pub enum Port {
Ephemeral(u64),
Handler(Uid),
Control(ControlPort),
}Expand description
A port identifier within an actor.
Variants
Ephemeral(u64)
Ephemeral ports, indexed starting at 0.
Handler(Uid)
Handler ports, indexed by uid. The label usually carries the type name.
Control(ControlPort)
Control ports.
Implementations
Sourceimpl Port
impl Port
Sourcepub fn is_ephemeral(&self) -> bool
pub fn is_ephemeral(&self) -> bool
Returns true if this is a Port::Ephemeral, otherwise false
Sourcepub fn as_ephemeral_mut(&mut self) -> Option<&mut u64>
pub fn as_ephemeral_mut(&mut self) -> Option<&mut u64>
Optionally returns mutable references to the inner fields if this is a Port::Ephemeral, otherwise None
Sourcepub fn as_ephemeral(&self) -> Option<&u64>
pub fn as_ephemeral(&self) -> Option<&u64>
Optionally returns references to the inner fields if this is a Port::Ephemeral, otherwise None
Sourcepub fn into_ephemeral(self) -> Result<u64, Self>
pub fn into_ephemeral(self) -> Result<u64, Self>
Returns the inner fields if this is a Port::Ephemeral, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_handler(&self) -> bool
pub fn is_handler(&self) -> bool
Returns true if this is a Port::Handler, otherwise false
Sourcepub fn as_handler_mut(&mut self) -> Option<&mut Uid>
pub fn as_handler_mut(&mut self) -> Option<&mut Uid>
Optionally returns mutable references to the inner fields if this is a Port::Handler, otherwise None
Sourcepub fn as_handler(&self) -> Option<&Uid>
pub fn as_handler(&self) -> Option<&Uid>
Optionally returns references to the inner fields if this is a Port::Handler, otherwise None
Sourcepub fn into_handler(self) -> Result<Uid, Self>
pub fn into_handler(self) -> Result<Uid, Self>
Returns the inner fields if this is a Port::Handler, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_control(&self) -> bool
pub fn is_control(&self) -> bool
Returns true if this is a Port::Control, otherwise false
Sourcepub fn as_control_mut(&mut self) -> Option<&mut ControlPort>
pub fn as_control_mut(&mut self) -> Option<&mut ControlPort>
Optionally returns mutable references to the inner fields if this is a Port::Control, otherwise None
Sourcepub fn as_control(&self) -> Option<&ControlPort>
pub fn as_control(&self) -> Option<&ControlPort>
Optionally returns references to the inner fields if this is a Port::Control, otherwise None
Sourcepub fn into_control(self) -> Result<ControlPort, Self>
pub fn into_control(self) -> Result<ControlPort, Self>
Returns the inner fields if this is a Port::Control, otherwise returns back the enum in the Err case of the result
Sourceimpl Port
impl Port
Sourcepub fn handler_id(typehash: u64, label: Option<Label>) -> Self
pub fn handler_id(typehash: u64, label: Option<Label>) -> Self
Create a handler port from a type hash and optional display label.
Sourcepub fn control(port: ControlPort) -> Self
pub fn control(port: ControlPort) -> Self
Create a control port.
Sourcepub fn ephemeral_index(&self) -> Option<u64>
pub fn ephemeral_index(&self) -> Option<u64>
The ephemeral port index, if this is an ephemeral port.